/*******************************************************************************
* File Name: Pwm.h
* Version 1.0
*
* Description:
*  This file provides constants and parameter values for the Pwm
*  component.
*
********************************************************************************
* Copyright 2016-2017, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(Pwm_CY_TCPWM_PWM_PDL_H)
#define Pwm_CY_TCPWM_PWM_PDL_H

#include "cyfitter.h"
#include "tcpwm/cy_tcpwm_pwm.h"

   
/*******************************************************************************
* Variables
*******************************************************************************/
/**
* \addtogroup group_globals
* @{
*/
extern uint8_t  Pwm_initVar;
extern cy_stc_tcpwm_pwm_config_t const Pwm_config;
/** @} group_globals */


/***************************************
*        Function Prototypes
****************************************/
/**
* \addtogroup group_general
* @{
*/
void Pwm_Start(void);
__STATIC_INLINE cy_en_tcpwm_status_t Pwm_Init(cy_stc_tcpwm_pwm_config_t const *config);
__STATIC_INLINE void Pwm_DeInit(void);
__STATIC_INLINE void Pwm_Enable(void);
__STATIC_INLINE void Pwm_Disable(void);
__STATIC_INLINE uint32_t Pwm_GetStatus(void);
__STATIC_INLINE void Pwm_SetCompare0(uint32_t compare0);
__STATIC_INLINE uint32_t Pwm_GetCompare0(void);
__STATIC_INLINE void Pwm_SetCompare1(uint32_t compare1);
__STATIC_INLINE uint32_t Pwm_GetCompare1(void);
__STATIC_INLINE void Pwm_EnableCompareSwap(bool enable);
__STATIC_INLINE void Pwm_SetCounter(uint32_t count);
__STATIC_INLINE uint32_t Pwm_GetCounter(void);
__STATIC_INLINE void Pwm_SetPeriod0(uint32_t period0);
__STATIC_INLINE uint32_t Pwm_GetPeriod0(void);
__STATIC_INLINE void Pwm_SetPeriod1(uint32_t period1);
__STATIC_INLINE uint32_t Pwm_GetPeriod1(void);
__STATIC_INLINE void Pwm_EnablePeriodSwap(bool enable);
__STATIC_INLINE void Pwm_TriggerStart(void);
__STATIC_INLINE void Pwm_TriggerReload(void);
__STATIC_INLINE void Pwm_TriggerKill(void);
__STATIC_INLINE void Pwm_TriggerSwap(void);
__STATIC_INLINE uint32_t Pwm_GetInterruptStatus(void);
__STATIC_INLINE void Pwm_ClearInterrupt(uint32_t source);
__STATIC_INLINE void Pwm_SetInterrupt(uint32_t source);
__STATIC_INLINE void Pwm_SetInterruptMask(uint32_t mask);
__STATIC_INLINE uint32_t Pwm_GetInterruptMask(void);
__STATIC_INLINE uint32_t Pwm_GetInterruptStatusMasked(void);
/** @} general */


/***************************************
*           API Constants
***************************************/

/**
* \addtogroup group_macros
* @{
*/
/** This is a ptr to the base address of the TCPWM instance */
#define Pwm_HW                 (Pwm_TCPWM__HW)

/** This is a ptr to the base address of the TCPWM CNT instance */
#define Pwm_CNT_HW             (Pwm_TCPWM__CNT_HW)

/** This is the counter instance number in the selected TCPWM */
#define Pwm_CNT_NUM            (Pwm_TCPWM__CNT_IDX)

/** This is the bit field representing the counter instance in the selected TCPWM */
#define Pwm_CNT_MASK           (1UL << Pwm_CNT_NUM)
/** @} group_macros */

#define Pwm_INPUT_MODE_MASK    (0x3U)
#define Pwm_INPUT_DISABLED     (7U)


/*******************************************************************************
* Function Name: Pwm_Init
****************************************************************************//**
*
* Invokes the Cy_TCPWM_PWM_Init() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE cy_en_tcpwm_status_t Pwm_Init(cy_stc_tcpwm_pwm_config_t const *config)
{
    return(Cy_TCPWM_PWM_Init(Pwm_HW, Pwm_CNT_NUM, config));
}


/*******************************************************************************
* Function Name: Pwm_DeInit
****************************************************************************//**
*
* Invokes the Cy_TCPWM_PWM_DeInit() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void Pwm_DeInit(void)                   
{
    Cy_TCPWM_PWM_DeInit(Pwm_HW, Pwm_CNT_NUM, &Pwm_config);
}

/*******************************************************************************
* Function Name: Pwm_Enable
****************************************************************************//**
*
* Invokes the Cy_TCPWM_Enable_Multiple() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void Pwm_Enable(void)                   
{
    Cy_TCPWM_Enable_Multiple(Pwm_HW, Pwm_CNT_MASK);
}


/*******************************************************************************
* Function Name: Pwm_Disable
****************************************************************************//**
*
* Invokes the Cy_TCPWM_Disable_Multiple() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void Pwm_Disable(void)                  
{
    Cy_TCPWM_Disable_Multiple(Pwm_HW, Pwm_CNT_MASK);
}


/*******************************************************************************
* Function Name: Pwm_GetStatus
****************************************************************************//**
*
* Invokes the Cy_TCPWM_PWM_GetStatus() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t Pwm_GetStatus(void)                
{
    return(Cy_TCPWM_PWM_GetStatus(Pwm_HW, Pwm_CNT_NUM));
}


/*******************************************************************************
* Function Name: Pwm_SetCompare0
****************************************************************************//**
*
* Invokes the Cy_TCPWM_PWM_SetCompare0() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void Pwm_SetCompare0(uint32_t compare0)      
{
    Cy_TCPWM_PWM_SetCompare0(Pwm_HW, Pwm_CNT_NUM, compare0);
}


/*******************************************************************************
* Function Name: Pwm_GetCompare0
****************************************************************************//**
*
* Invokes the Cy_TCPWM_PWM_GetCompare0() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t Pwm_GetCompare0(void)              
{
    return(Cy_TCPWM_PWM_GetCompare0(Pwm_HW, Pwm_CNT_NUM));
}


/*******************************************************************************
* Function Name: Pwm_SetCompare1
****************************************************************************//**
*
* Invokes the Cy_TCPWM_PWM_SetCompare1() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void Pwm_SetCompare1(uint32_t compare1)      
{
    Cy_TCPWM_PWM_SetCompare1(Pwm_HW, Pwm_CNT_NUM, compare1);
}


/*******************************************************************************
* Function Name: Pwm_GetCompare1
****************************************************************************//**
*
* Invokes the Cy_TCPWM_PWM_GetCompare1() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t Pwm_GetCompare1(void)              
{
    return(Cy_TCPWM_PWM_GetCompare1(Pwm_HW, Pwm_CNT_NUM));
}


/*******************************************************************************
* Function Name: Pwm_EnableCompareSwap
****************************************************************************//**
*
* Invokes the Cy_TCPWM_PWM_EnableCompareSwap() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void Pwm_EnableCompareSwap(bool enable)  
{
    Cy_TCPWM_PWM_EnableCompareSwap(Pwm_HW, Pwm_CNT_NUM, enable);
}


/*******************************************************************************
* Function Name: Pwm_SetCounter
****************************************************************************//**
*
* Invokes the Cy_TCPWM_PWM_SetCounter() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void Pwm_SetCounter(uint32_t count)          
{
    Cy_TCPWM_PWM_SetCounter(Pwm_HW, Pwm_CNT_NUM, count);
}


/*******************************************************************************
* Function Name: Pwm_GetCounter
****************************************************************************//**
*
* Invokes the Cy_TCPWM_PWM_GetCounter() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t Pwm_GetCounter(void)               
{
    return(Cy_TCPWM_PWM_GetCounter(Pwm_HW, Pwm_CNT_NUM));
}


/*******************************************************************************
* Function Name: Pwm_SetPeriod0
****************************************************************************//**
*
* Invokes the Cy_TCPWM_PWM_SetPeriod0() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void Pwm_SetPeriod0(uint32_t period0)          
{
    Cy_TCPWM_PWM_SetPeriod0(Pwm_HW, Pwm_CNT_NUM, period0);
}


/*******************************************************************************
* Function Name: Pwm_GetPeriod0
****************************************************************************//**
*
* Invokes the Cy_TCPWM_PWM_GetPeriod0() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t Pwm_GetPeriod0(void)                
{
    return(Cy_TCPWM_PWM_GetPeriod0(Pwm_HW, Pwm_CNT_NUM));
}


/*******************************************************************************
* Function Name: Pwm_SetPeriod1
****************************************************************************//**
*
* Invokes the Cy_TCPWM_PWM_SetPeriod1() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void Pwm_SetPeriod1(uint32_t period1)
{
    Cy_TCPWM_PWM_SetPeriod1(Pwm_HW, Pwm_CNT_NUM, period1);
}


/*******************************************************************************
* Function Name: Pwm_GetPeriod1
****************************************************************************//**
*
* Invokes the Cy_TCPWM_PWM_GetPeriod1() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t Pwm_GetPeriod1(void)                
{
    return(Cy_TCPWM_PWM_GetPeriod1(Pwm_HW, Pwm_CNT_NUM));
}


/*******************************************************************************
* Function Name: Pwm_EnablePeriodSwap
****************************************************************************//**
*
* Invokes the Cy_TCPWM_PWM_EnablePeriodSwap() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void Pwm_EnablePeriodSwap(bool enable)
{
    Cy_TCPWM_PWM_EnablePeriodSwap(Pwm_HW, Pwm_CNT_NUM, enable);
}


/*******************************************************************************
* Function Name: Pwm_TriggerStart
****************************************************************************//**
*
* Invokes the Cy_TCPWM_TriggerStart() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void Pwm_TriggerStart(void)             
{
    Cy_TCPWM_TriggerStart(Pwm_HW, Pwm_CNT_MASK);
}


/*******************************************************************************
* Function Name: Pwm_TriggerReload
****************************************************************************//**
*
* Invokes the Cy_TCPWM_TriggerReloadOrIndex() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void Pwm_TriggerReload(void)     
{
    Cy_TCPWM_TriggerReloadOrIndex(Pwm_HW, Pwm_CNT_MASK);
}


/*******************************************************************************
* Function Name: Pwm_TriggerKill
****************************************************************************//**
*
* Invokes the Cy_TCPWM_TriggerStopOrKill() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void Pwm_TriggerKill(void)
{
    Cy_TCPWM_TriggerStopOrKill(Pwm_HW, Pwm_CNT_MASK);
}


/*******************************************************************************
* Function Name: Pwm_TriggerSwap
****************************************************************************//**
*
* Invokes the Cy_TCPWM_TriggerCaptureOrSwap() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void Pwm_TriggerSwap(void)     
{
    Cy_TCPWM_TriggerCaptureOrSwap(Pwm_HW, Pwm_CNT_MASK);
}


/*******************************************************************************
* Function Name: Pwm_GetInterruptStatus
****************************************************************************//**
*
* Invokes the Cy_TCPWM_GetInterruptStatus() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t Pwm_GetInterruptStatus(void)       
{
    return(Cy_TCPWM_GetInterruptStatus(Pwm_HW, Pwm_CNT_NUM));
}


/*******************************************************************************
* Function Name: Pwm_ClearInterrupt
****************************************************************************//**
*
* Invokes the Cy_TCPWM_ClearInterrupt() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void Pwm_ClearInterrupt(uint32_t source)     
{
    Cy_TCPWM_ClearInterrupt(Pwm_HW, Pwm_CNT_NUM, source);
}


/*******************************************************************************
* Function Name: Pwm_SetInterrupt
****************************************************************************//**
*
* Invokes the Cy_TCPWM_SetInterrupt() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void Pwm_SetInterrupt(uint32_t source)
{
    Cy_TCPWM_SetInterrupt(Pwm_HW, Pwm_CNT_NUM, source);
}


/*******************************************************************************
* Function Name: Pwm_SetInterruptMask
****************************************************************************//**
*
* Invokes the Cy_TCPWM_SetInterruptMask() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void Pwm_SetInterruptMask(uint32_t mask)     
{
    Cy_TCPWM_SetInterruptMask(Pwm_HW, Pwm_CNT_NUM, mask);
}


/*******************************************************************************
* Function Name: Pwm_GetInterruptMask
****************************************************************************//**
*
* Invokes the Cy_TCPWM_GetInterruptMask() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t Pwm_GetInterruptMask(void)         
{
    return(Cy_TCPWM_GetInterruptMask(Pwm_HW, Pwm_CNT_NUM));
}


/*******************************************************************************
* Function Name: Pwm_GetInterruptStatusMasked
****************************************************************************//**
*
* Invokes the Cy_TCPWM_GetInterruptStatusMasked() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t Pwm_GetInterruptStatusMasked(void)
{
    return(Cy_TCPWM_GetInterruptStatusMasked(Pwm_HW, Pwm_CNT_NUM));
}

#endif /* Pwm_CY_TCPWM_PWM_PDL_H */


/* [] END OF FILE */
